==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebDensityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDetailDescriptionMetadata } from "./WebDensityChangedEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDescription } from "./WebDensityChangedEventArgsDescription";
/**
 * @hidden
 */
var WebDensityChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDensityChangedEventArgsDescriptionMetadata, _super);
    function WebDensityChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDensityChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebDensityChangedEventArgsDescriptionMetadata.a == null) {
            WebDensityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDensityChangedEventArgsDescriptionMetadata.c(WebDensityChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebDensityChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDensityChangedEventArgsDescriptionMetadata.a);
        WebDensityChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebDensityChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DensityChangedEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebDensityChangedEventArgsDetail");
    };
    WebDensityChangedEventArgsDescriptionMetadata.d = function (a) {
        WebDensityChangedEventArgsDescriptionMetadata.b(a);
        a.aa("WebDensityChangedEventArgs", function () { return new WebDensityChangedEventArgsDescription(); });
        a.z("WebDensityChangedEventArgs", WebDensityChangedEventArgsDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDescriptionMetadata.$t = markType(WebDensityChangedEventArgsDescriptionMetadata, 'WebDensityChangedEventArgsDescriptionMetadata');
    WebDensityChangedEventArgsDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDescriptionMetadata;
}(Base));
export { WebDensityChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebDensityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDensityChangedEventArgsDetailDescriptionMetadata } from "./WebDensityChangedEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDescription } from "./WebDensityChangedEventArgsDescription";
/**
 * @hidden
 */
var WebDensityChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDensityChangedEventArgsDescriptionMetadata, _super);
    function WebDensityChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDensityChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebDensityChangedEventArgsDescriptionMetadata.a == null) {
            WebDensityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDensityChangedEventArgsDescriptionMetadata.c(WebDensityChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebDensityChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebDensityChangedEventArgsDescriptionMetadata.a);
        WebDensityChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebDensityChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DensityChangedEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebDensityChangedEventArgsDetail");
    };
    WebDensityChangedEventArgsDescriptionMetadata.d = function (a) {
        WebDensityChangedEventArgsDescriptionMetadata.b(a);
        a.ac("WebDensityChangedEventArgs", function () { return new WebDensityChangedEventArgsDescription(); });
        a.ab("WebDensityChangedEventArgs", WebDensityChangedEventArgsDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDescriptionMetadata.$t = markType(WebDensityChangedEventArgsDescriptionMetadata, 'WebDensityChangedEventArgsDescriptionMetadata');
    WebDensityChangedEventArgsDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDescriptionMetadata;
}(Base));
export { WebDensityChangedEventArgsDescriptionMetadata };
